==> libpdsnn-0.03.0.tar.gz: libpdsnn-0.03.0/src/headers/pds/pdsnnglobal.h <==
/*
 * pdsnnglobal.h
 * 
 * Copyright 2011 Fernando Pujaico Rivera <fernando.pujaico.rivera@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */

/** \file pdsnnglobal.h
 *  \author Fernando Pujaico Rivera
 *  \date 31-12-2011
 *  \brief Variables globales y definciones de la biblioteca pdsnn.
 *  
 *  <br><br>Aquí Estarán definidas las variables globales que serán usadas en
 *  toda la biblioteca pdsnn.
 */

#ifndef __PDSNNGLOBAL_H__
#define __PDSNNGLOBAL_H__

#include <stdio.h>

#ifdef __cplusplus
extern "C" {
#endif 

/** \defgroup PdsNnGlobalGroup Definiciones globales de la biblioteca PdsNn.
 * @{
 */

/*! Defino el tipo de variable real como PdsNnReal.
 *  \ingroup PdsNnGlobalGroup
 */
typedef float PdsNnReal;

/*! Defino el tipo de variable entero como PdsNnInteger.
 *  \ingroup PdsNnGlobalGroup
 */
typedef int PdsNnInteger;

/*! Defino el tipo de variable natural (incluye cero) como PdsNnNatural.
 *  \ingroup PdsNnGlobalGroup
 */
typedef unsigned int PdsNnNatural;


/*! Defino el tipo de variable unsigned char como PdsNnUChar.
 *  \ingroup PdsNnGlobalGroup
 */
typedef unsigned char PdsNnBool;

/**
 * @}
 */


#ifdef __cplusplus
}
#endif 

#endif /* __PDSNNGLOBAL_H__ */

==> libpdsnn-0.04.0.tar.gz: libpdsnn-0.04.0/src/headers/pds/pdsnnglobal.h <==
/*
 * pdsnnglobal.h
 * 
 * Copyright 2011 Fernando Pujaico Rivera <fernando.pujaico.rivera@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */

/** \file pdsnnglobal.h
 *  \author Fernando Pujaico Rivera
 *  \date 31-12-2011
 *  \brief Variables globales y definciones de la biblioteca pdsnn.
 *  
 *  Aquí Estarán definidas las variables globales que serán usadas en
 *  toda la biblioteca pdsnn.
 */

#ifndef __PDSNNGLOBAL_H__
#define __PDSNNGLOBAL_H__

#include <stdio.h>

#ifdef __cplusplus
extern "C" {
#endif 

/** \defgroup PdsNnGlobalGroup Definiciones globales.
 *  \brief Variables globales y definciones de la biblioteca pdsnn.
 *  
 *  Aquí Estarán definidas las variables globales que serán usadas en
 *  toda la biblioteca pdsnn.
 * @{
 */

/*! Defino el tipo de variable real como PdsNnReal.
 *  \ingroup PdsNnGlobalGroup
 */
typedef float PdsNnReal;

/*! Defino el tipo de variable entero como PdsNnInteger.
 *  \ingroup PdsNnGlobalGroup
 */
typedef int PdsNnInteger;

/*! Defino el tipo de variable natural (incluye cero) como PdsNnNatural.
 *  \ingroup PdsNnGlobalGroup
 */
typedef unsigned int PdsNnNatural;


/*! Defino el tipo de variable unsigned char como PdsNnUChar.
 *  \ingroup PdsNnGlobalGroup
 */
typedef unsigned char PdsNnBool;

/**
 * @}
 */


#ifdef __cplusplus
}
#endif 

#endif /* __PDSNNGLOBAL_H__ */
